Range

Struct Range 

pub struct Range { /* private fields */ }
Specify an optionally opened range of time. Times are stored in UTC and expected to be given in UTC time.

Implementations

Source

impl Range

pub fn pretty_duration(d: &Duration) -> String

Print the duration in a HH:MM:SS format

pub fn new(from: DateTime<Utc>, to: Option<DateTime<Utc>>) -> Result<Range>

Create a new Range with the specified from and to

pub fn day(day: &DateTime<Local>) -> Result<Range>

Create a new Range representing the day containing the given date/time

pub fn today() -> Result<Range>

Create a Range representing today

pub fn yesterday() -> Result<Range>

Create a Range representing yesterday

pub fn week(day: &DateTime<Local>) -> Result<Range>

Create a new Range representing the week containing the given date/time

pub fn current_week() -> Result<Range>

Create a Range representing the current week

pub fn last_week() -> Result<Range>

Create a Range representing last week

pub fn month(day: &DateTime<Local>) -> Result<Range>

Create a new Range representing the month containing the given date/time

pub fn current_month() -> Result<Range>

Create a Range representing the current month

pub fn last_month() -> Result<Range>

Create a Range representing the last month

pub fn is_open(&self) -> bool

Return true if the range is open. An open range is a Range that has no end set.

pub fn intersection(&self, other: &Range) -> Option<Range>

Return the intersection with another Range, if any.

pub fn duration(&self) -> Duration

Return the duration of a Range

pub fn days(&self) -> Vec<DateTime<Utc>>

Return the number of days in the Range

pub fn split_at(&self, date: DateTime<Utc>) -> Result<(Range, Range)>

Split the Range at the given date/time in 2 new Range elements

pub fn split(&self) -> Result<(Range, Range)>

Split the Range at middle in 2 new Range elements